@@ -1,5 +1,5 @@
 package Net::Braintree::ResultObject;
-use Net::Braintree::Util qw(is_array is_hash);
+use Net::Braintree::Util qw(is_arrayref is_hashref);
 use Moose;
 
 my $meta = __PACKAGE__->meta;
@@ -15,9 +15,9 @@ sub set_attributes_from_hash {
 sub set_attr_value {
   my ($self, $value) = @_;
 
-  if(is_hash($value)) {
+  if(is_hashref($value)) {
     return Hash::Inflator->new($value);
-  } elsif(is_array($value)) {
+  } elsif(is_arrayref($value)) {
     my $new_array = [];
     foreach(@$value) {
       push(@$new_array, $self->set_attr_value($_));
@@ -32,14 +32,14 @@ sub setup_sub_objects {
   my($self, $target, $params, $sub_objects) = @_;
   while(my($attribute, $class) = each(%$sub_objects)) {
     $meta->add_attribute($attribute, is => 'rw');
-    if (is_array($params->{$attribute})) {
+    if (is_arrayref($params->{$attribute})) {
       my $new_array = [];
       foreach my $element (@{$params->{$attribute}}) {
-        push(@$new_array, $class->new($element)) if is_hash($element);
+        push(@$new_array, $class->new($element)) if is_hashref($element);
       }
       $target->$attribute($new_array);
     } else {
-      push(@{$target->$attribute}, $class->new($params->{$attribute})) if is_hash($params->{$attribute});
+      push(@{$target->$attribute}, $class->new($params->{$attribute})) if is_hashref($params->{$attribute});
     }
     delete($params->{$attribute});
   }
